﻿#region License Information
/* HeuristicLab
 * Copyright (C) 2002-2016 Heuristic and Evolutionary Algorithms Laboratory (HEAL)
 *
 * This file is part of HeuristicLab.
 *
 * HeuristicLab is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * HeuristicLab is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HeuristicLab. If not, see <http://www.gnu.org/licenses/>.
 */
#endregion

using System.Drawing;
using System.Threading.Tasks;
using HeuristicLab.Core.Networks;
using HeuristicLab.Visualization;

namespace HeuristicLab.Networks.Views.NetworkVisualization {
  [Primitive(typeof(IMessagePort), true)]
  public class MessagePortRectangle : PortRectangle {
    protected readonly Brush IdleBrush;
    protected readonly Brush MessageSentBrush = Brushes.Yellow;
    protected readonly Brush MessageReceivedBrush = Brushes.Red;

    public new IMessagePort NetworkItem {
      get { return (IMessagePort)base.NetworkItem; }
      set { base.NetworkItem = value; }
    }

    public MessagePortRectangle(IChart chart, IMessagePort port, INode node)
      : base(chart, port, node) {
      IdleBrush = new SolidBrush(VisualProperties.BrushColor);
      port.MessageSent += (sender, args) => Highlight(MessageSentBrush);
      port.MessageReceived += (sender, args) => Highlight(MessageReceivedBrush);
    }

    private async Task Highlight(Brush brush) {
      Brush = brush;
      await Task.Delay(200);
      Brush = IdleBrush;
    }
  }
}
